# Generated by Django 2.2 on 2019-04-14 08:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0016_auto_20190414_0758'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='user_permission',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='usergroup',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='usergroup_permission',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='widgets_trees',
            name='deleted_at',
        ),
    ]
